@@ -1,21 +1,18 @@
-#--
-# Copyright 2006 Luke Kanies <luke@madstop.com>
+# Facter - Host Fact Detection and Reporting
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
+# Copyright 2011 Puppet Labs Inc
 #
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# http://www.apache.org/licenses/LICENSE-2.0
 #
-#--
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 module Facter
     # This is just so the other classes have the constant.
@@ -27,7 +24,7 @@ module Facter
     include Comparable
     include Enumerable
 
-    FACTERVERSION = '1.5.8'
+    FACTERVERSION = '1.6.0'
     # = Facter
     # Functions as a hash of 'facts' you might care about about your
     # system, such as mac address, IP address, Video card, etc.
@@ -48,6 +45,7 @@ module Facter
     GREEN = "[0;32m"
     RESET = "[0m"
     @@debug = 0
+    @@timing = 0
 
     # module methods
 
@@ -77,6 +75,15 @@ module Facter
         @@debug != 0
     end
 
+    # show the timing information
+    def self.show_time(string)
+        puts "#{GREEN}#{string}#{RESET}" if string and Facter.timing?
+    end
+
+    def self.timing?
+        @@timing != 0
+    end
+
     # Return a fact object by name.  If you use this, you still have to call
     # 'value' on it to retrieve the actual value.
     def self.[](name)
@@ -177,6 +184,22 @@ module Facter
         end
     end
 
+    # Set timing on or off.
+    def self.timing(bit)
+        if bit
+            case bit
+            when TrueClass; @@timing = 1
+            when Fixnum
+                if bit > 0
+                    @@timing = 1
+                else
+                    @@timing = 0
+                end
+            end
+        else
+            @@timing = 0
+        end
+    end
 
     def self.warn(msg)
         if Facter.debugging? and msg and not msg.empty?
