@@ -1,3 +1,27 @@
+# Fact: ipaddress
+#
+# Purpose: Return the main IP address for a host.
+#
+# Resolution:
+#   On the Unixes does an ifconfig, and returns the first non 127.0.0.0/8
+#   subnetted IP it finds.
+#   On Windows, it attempts to use the socket library and resolve the machine's
+#   hostname via DNS.
+#
+#   On LDAP based hosts it tries to use either the win32/resolv library to
+#   resolve the hostname to an IP address, or on Unix, it uses the resolv
+#   library.
+#
+#   As a fall back for undefined systems, it tries to run the "host" command to
+#   resolve the machine's hostname using the system DNS.
+#
+# Caveats:
+#   DNS resolution relies on working DNS infrastructure and resolvers on the
+#   host system.
+#   The ifconfig parsing purely takes the first IP address it finds without any
+#   checking this is a useful IP address.
+#
+
 Facter.add(:ipaddress) do
     confine :kernel => :linux
     setcode do
@@ -7,7 +31,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet addr:([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -19,7 +43,7 @@ Facter.add(:ipaddress) do
 end
 
 Facter.add(:ipaddress) do
-    confine :kernel => %w{FreeBSD OpenBSD solaris}
+    confine :kernel => %w{FreeBSD OpenBSD Darwin}
     setcode do
         ip = nil
         output = %x{/sbin/ifconfig}
@@ -27,7 +51,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -39,7 +63,7 @@ Facter.add(:ipaddress) do
 end
 
 Facter.add(:ipaddress) do
-    confine :kernel => %w{NetBSD}
+    confine :kernel => %w{NetBSD SunOS}
     setcode do
         ip = nil
         output = %x{/sbin/ifconfig -a}
@@ -47,38 +71,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
-                    ip = tmp
-                    break
-                end
-            end
-        }
-
-        ip
-    end
-end
-
-Facter.add(:ipaddress) do
-    confine :kernel => %w{darwin}
-    setcode do
-        ip = nil
-        iface = ""
-        output = %x{/usr/sbin/netstat -rn}
-        if output =~ /^default\s*\S*\s*\S*\s*\S*\s*\S*\s*(\S*).*/
-          iface = $1
-        else
-          warn "Could not find a default route. Using first non-loopback interface"
-        end
-        if(iface != "")
-          output = %x{/sbin/ifconfig #{iface}}
-        else
-          output = %x{/sbin/ifconfig}
-        end
-
-        output.split(/^\S/).each { |str|
-            if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
-                tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./ or tmp == "0.0.0.0"
                     ip = tmp
                     break
                 end
@@ -98,7 +91,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -112,29 +105,26 @@ end
 Facter.add(:ipaddress) do
     confine :kernel => %w{windows}
     setcode do
-        ip = nil
-        output = %x{ipconfig}
-
-        output.split(/^\S/).each { |str|
-            if str =~ /IP Address.*: ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
-                tmp = $1
-                unless tmp =~ /127\./
-                    ip = tmp
-                    break
-                end
-            end
-        }
-        ip
+        require 'socket'
+        IPSocket.getaddress(Socket.gethostname)
     end
 end
 
 Facter.add(:ipaddress, :ldapname => "iphostnumber", :timeout => 2) do
     setcode do
-        require 'resolv'
-
+        if Facter.value(:kernel) == 'windows'
+            require 'win32/resolv'
+        else
+            require 'resolv'
+        end
+        
         begin
             if hostname = Facter.value(:hostname)
-                ip = Resolv.getaddress(hostname)
+                if Facter.value(:kernel) == 'windows'
+                    ip = Win32::Resolv.get_resolv_info.last[0]
+                else
+                    ip = Resolv.getaddress(hostname)                
+                end
                 unless ip == "127.0.0.1"
                     ip
                 end
