@@ -1,3 +1,16 @@
+# Fact: macosx
+#
+# Purpose:
+#   Returns a number of Mac specific facts, from system profiler and
+#   sw_vers.
+#
+# Resolution:
+#   Uses util/macosx.rb to do the fact reconnaissance, then outputs them
+#   preceded by 'sp_'
+#
+# Caveats:
+#
+
 #
 # macosx.rb
 # Additional Facts coming from Mac OS X system_profiler command
@@ -5,17 +18,6 @@
 # Copyright (C) 2007 Jeff McCune
 # Author: Jeff McCune <jeff.mccune@northstarlabs.net>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation (version 2 of the License)
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston MA    02110-1301 USA
-
 # Jeff McCune
 # There's a lot more information coming out of system_profiler -xml
 # We could add quite a bit more, but I didn't want to overload facter
@@ -25,7 +27,7 @@
 require 'facter/util/macosx'
 
 if Facter.value(:kernel) == "Darwin"
-    Facter::Macosx.hardware_overview.each do |fact, value|
+    Facter::Util::Macosx.hardware_overview.each do |fact, value|
         Facter.add("sp_#{fact}") do
             confine :kernel => :darwin
             setcode do
@@ -34,7 +36,7 @@ if Facter.value(:kernel) == "Darwin"
         end
     end
 
-    Facter::Macosx.os_overview.each do |fact, value|
+    Facter::Util::Macosx.os_overview.each do |fact, value|
         Facter.add("sp_#{fact}") do
             confine :kernel => :darwin
             setcode do
@@ -43,7 +45,7 @@ if Facter.value(:kernel) == "Darwin"
         end
     end
 
-    Facter::Macosx.sw_vers.each do |fact, value|
+    Facter::Util::Macosx.sw_vers.each do |fact, value|
         Facter.add(fact) do
             confine :kernel => :darwin
             setcode do
