@@ -1,67 +1,46 @@
+# Fact: operatingsystemrelease
+#
+# Purpose: Returns the release of the operating system.
+#
+# Resolution:
+#   On RedHat derivatives, returns their '/etc/<variant>-release' file.
+#   On Debian, returns '/etc/debian_version'.
+#   On Ubuntu, parses '/etc/issue' for the release version.
+#   On Suse, derivatives, parses '/etc/SuSE-release' for a selection of version
+#   information.
+#   On Slackware, parses '/etc/slackware-version'.
+#   
+#   On all remaining systems, returns the 'kernelrelease' value.
+#
+# Caveats:
+#
+
 Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => :fedora
+    confine :operatingsystem => %w{CentOS Fedora oel ovs RedHat MeeGo}
     setcode do
-        File::open("/etc/fedora-release", "r") do |f|
+        case Facter.value(:operatingsystem)
+        when "CentOS", "RedHat"
+            releasefile = "/etc/redhat-release"
+        when "Fedora"
+            releasefile = "/etc/fedora-release"
+        when "MeeGo"
+            releasefile = "/etc/meego-release"
+        when "OEL", "oel"
+            releasefile = "/etc/enterprise-release"
+        when "OVS", "ovs"
+            releasefile = "/etc/ovs-release"
+        end
+        File::open(releasefile, "r") do |f|
             line = f.readline.chomp
             if line =~ /\(Rawhide\)$/
                 "Rawhide"
-            elsif line =~ /release (\d+)/
+            elsif line =~ /release (\d[\d.]*)/
                 $1
             end
         end
     end
 end
 
-Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => %w{RedHat}
-    setcode do
-        File::open("/etc/redhat-release", "r") do |f|
-            line = f.readline.chomp
-            if line =~ /\(Rawhide\)$/
-                "Rawhide"
-            elsif line =~ /release (\d+)/
-                $1
-            end
-        end
-    end
-end
-
-Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => :oel
-    setcode do
-        File::open("/etc/enterprise-release", "r") do |f|
-            line = f.readline.chomp
-            if line =~ /release (\d+)/
-                $1
-            end
-        end
-    end
-end
-
-Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => :ovs
-    setcode do
-        File::open("/etc/ovs-release", "r") do |f|
-            line = f.readline.chomp
-            if line =~ /release (\d+)/
-                $1
-            end
-        end
-    end
-end
-
-Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => %w{CentOS}
-    setcode do
-        centos_release = Facter::Util::Resolution.exec("sed -r -e 's/CentOS release //' -e 's/ \\((Branch|Final)\\)//' /etc/redhat-release")
-        if centos_release =~ /^5/
-            release = Facter::Util::Resolution.exec('rpm -q --qf \'%{VERSION}.%{RELEASE}\' centos-release | cut -d. -f1,2')
-        else
-            release = centos_release
-        end
-    end
-end
-
 Facter.add(:operatingsystemrelease) do
     confine :operatingsystem => %w{Debian}
     setcode do
@@ -99,6 +78,50 @@ Facter.add(:operatingsystemrelease) do
     end
 end
 
+Facter.add(:operatingsystemrelease) do
+    confine :operatingsystem => %w{Slackware}
+    setcode do
+        release = Facter::Util::Resolution.exec('cat /etc/slackware-version')
+        if release =~ /Slackware ([0-9.]+)/
+            $1
+        end
+    end
+end
+
+Facter.add(:operatingsystemrelease) do
+    confine :operatingsystem => %w{Bluewhite64}
+    setcode do
+        releasefile = Facter::Util::Resolution.exec('cat /etc/bluewhite64-version')
+        if releasefile =~ /^\s*\w+\s+(\d+)\.(\d+)/
+            $1 + "." + $2
+        else
+            "unknown"
+        end
+    end
+end
+
+Facter.add(:operatingsystemrelease) do
+    confine :operatingsystem => %w{VMwareESX}
+    setcode do
+        release = Facter::Util::Resolution.exec('vmware -v')
+        if release =~ /VMware ESX .*?(\d.*)/
+            $1
+        end
+    end
+end
+
+Facter.add(:operatingsystemrelease) do
+    confine :operatingsystem => %w{Slamd64}
+    setcode do
+        releasefile = Facter::Util::Resolution.exec('cat /etc/slamd64-version')
+        if releasefile =~ /^\s*\w+\s+(\d+)\.(\d+)/
+            $1 + "." + $2
+        else
+            "unknown"
+        end
+    end
+end
+
 Facter.add(:operatingsystemrelease) do
     setcode do Facter[:kernelrelease].value end
 end
