@@ -4,17 +4,6 @@
 ## Copyright (C) 2007 Jeff McCune
 ## Author: Jeff McCune <jeff.mccune@northstarlabs.net>
 ##
-## This program is free software; you can redistribute it and/or
-## modify it under the terms of the GNU General Public License
-## as published by the Free Software Foundation (version 2 of the License)
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston MA  02110-1301 USA
-##
 
 module Facter::Util::Macosx
     require 'thread'
@@ -56,12 +45,16 @@ module Facter::Util::Macosx
     def self.sw_vers
         ver = Hash.new
         [ "productName", "productVersion", "buildVersion" ].each do |option|
-            ver["macosx_#{option}"] = %x{sw_vers -#{option}}.strip
+            ver["macosx_#{option}"] = Facter::Util::Resolution.exec("/usr/bin/sw_vers -#{option}").strip
         end
         productversion = ver["macosx_productVersion"]
         if not productversion.nil?
-            ver["macosx_productversion_major"] = productversion.scan(/(\d+\.\d+)/)[0][0]
-            ver["macosx_productversion_minor"] = productversion.scan(/(\d+)\.(\d+)\.(\d+)/)[0].last
+            versions = productversion.scan(/(\d+)\.(\d+)\.*(\d*)/)[0]
+            ver["macosx_productversion_major"] = "#{versions[0]}.#{versions[1]}"
+            if versions[2].empty?  # 10.x should be treated as 10.x.0
+                versions[2] = "0"
+            end
+            ver["macosx_productversion_minor"] = versions[2]
         end
         ver
     end
